/*
 * http://www.wayforward.net/avGPS/libav/av_dir.c
 * Copyright(c) 2005, 2008 Wayforward LLC
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */
#include "av_dir.h"
#include "av_err.h"

static const tchar_t OPENDIR_FN[] = T("opendir");
static const tchar_t READDIR_FN[] = T("readdir");

const char *
dir_first(const char *fn, struct directory *pd) {
	const char *result;

	pd->dp = opendir(fn);

	if (pd->dp == NULL) {
		err_push_errno(OPENDIR_FN, fn);
		return NULL;
	}

	result = dir_next(pd);

	if (result == NULL) {
		err_push_errno(READDIR_FN, fn);
		dir_close(pd);
	}

	return result;
}

const char *
dir_next(struct directory *pd) {
	while ((pd->de = readdir(pd->dp)) != NULL) {
		if (pd->de->d_name[0] != '.') {
			return pd->de->d_name;
		}
	}

	return NULL;
}

void
dir_close(struct directory *pd) {
	closedir(pd->dp);
}

/*
 * Overrides for Emacs so that we follow Linux's tabbing style.
 * Emacs will notice this stuff at the end of the file and automatically
 * adjust the settings for this buffer only.  This must remain at the
 * end of the file.
 * ----------------------------------------------------------------------
 * Local Variables:
 * c-file-style: "linux"
 * End:
 */
