/**
 * http://www.wayforward.net/avGPS/include/av_mem.h
 * Copyright(c) 2005, 2008 Wayforward LLC
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Abstraction/porting for memory-mapped files.  Works with
 * POSIX: mmap() and Windows: CreateViewOfFile
 */
#ifndef AV_MEM_H
#define AV_MEM_H

#include "av_str.h"

#ifdef __cplusplus
extern "C" {
#endif

# ifdef _WIN32
#  define WIN32_LEAN_AND_MEAN
#  include <windows.h>

	struct mapped_file {
		HANDLE hFile;
		HANDLE hMapping;

		const void *pv;
		size_t len;
	};

# else
	struct mapped_file {
		int fd;
		size_t len;
		const void *pv;
	};

# endif


	extern int
	map_file(const tchar_t *filename, struct mapped_file *pmf);

	extern void
	unmap_file(struct mapped_file *pmf);

#ifdef __cplusplus
}
#endif

#endif /* AV_MEM_H */

/*
 * Overrides for Emacs so that we follow Linux's tabbing style.
 * Emacs will notice this stuff at the end of the file and automatically
 * adjust the settings for this buffer only.  This must remain at the
 * end of the file.
 * ----------------------------------------------------------------------
 * Local Variables:
 * c-file-style: "linux"
 * End:
 */
