/**
 * http://www.wayforward.net/avGPS/libav/av_time_win.c
 * Copyright(c) 2005, 2008 Wayforward LLC
 * ---------------------------------------------------------------------
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

#include "av_time.h"

/* value in WIN32 FILETIME format of Jan 1, 2000 */
static const av_usecs win_epoch = 0x01bf53eb256d4000;

void
av_now(struct av_datetime *pdt) {

	SYSTEMTIME st;

	GetSystemTime(&st);

	pdt->date.year = st.wYear;
	pdt->date.month = (unsigned char) st.wMonth;
	pdt->date.day = (unsigned char) st.wDay;
	pdt->time.hour = (unsigned char) st.wHour;
	pdt->time.min = (unsigned char) st.wMinute;
	pdt->time.sec = (unsigned char) st.wSecond;
	pdt->time.usecs = st.wMilliseconds * 1000;
}

av_usecs
av_datetime_to_usecs(struct av_datetime dt) {
	SYSTEMTIME st;
	FILETIME ft;

	st.wYear = dt.date.year;
	st.wMonth = dt.date.month;
	st.wDay = dt.date.day;

	st.wHour = dt.time.hour;
	st.wMinute = dt.time.min;
	st.wSecond = dt.time.sec;
	st.wMilliseconds = dt.time.usecs / 1000;

	SystemTimeToFileTime(&st, &ft);

	return ((*(av_usecs *) &ft) - win_epoch) / 10;
}

double
av_julian(struct av_datetime dt) {
	return 2000.0 + av_datetime_to_usecs(dt) / (1000000.0 * 86400.0 * 365.2422);
}

/*
 * Overrides for Emacs so that we follow Linux's tabbing style.
 * Emacs will notice this stuff at the end of the file and automatically
 * adjust the settings for this buffer only.  This must remain at the
 * end of the file.
 * ----------------------------------------------------------------------
 * Local Variables:
 * c-file-style: "linux"
 * End:
 */
