VERSION=0.2

CYCLE := +1
YYMMDD := $(shell scripts/av_cycle -dacs ${CYCLE})
DOFYMD := $(shell scripts/av_cycle -dof ${CYCLE})
D := $(shell scripts/av_cycle ${CYCLE})
R := routes_${D}
T := tmp_${D}

FADDS := $(shell scripts/av_cycle -fadds ${CYCLE})

.PHONY: all sgb downloads download_sgb clean reallyclean csv nav_db

all : downloads nav_db dist/index.html
sgb : routes_${D}.gb

downloads : dist/routes_${D}.db.bz2 dist/routes_${D}.db.gz \
		dist/routes_${D}_db.zip dist/routes_${D}.zip \
		dist/routes_${D}.tar.bz2 dist/routes_${D}.tar.gz \
		dist/nav-${D}.led dist/nav-${D}.bed

download_sgb : dist/routes_${D}.gb.gz dist/routes_${D}.gb.bz2 \
		dist/routes_${D}_gb.zip

##################
# Documentation...
#
dist/index.html dist/design.html : templates/index.html \
	templates/design.html docs.xml dist/routes.sql dist/shortest_path.c | dist
	scripts/av_publish "num_airports=`tail -n +3 ${R}/airports.csv | wc -l`" \
			"num_runways=`tail -n +3 ${R}/runways.csv | wc -l`" \
			"num_navaids=`tail -n +3 ${R}/navaids.csv | wc -l`" \
			"num_fixes=`tail -n +3 ${R}/fixes.csv | wc -l`" \
			"num_routes=`tail -n +3 ${R}/routes.csv | wc -l`" \
			outdir=dist date=${D} docs.xml

# ...documentation
##################

#################################
# Comma-Separated Values (CSV)...
#
CSV = ${R}/airports.csv ${R}/runways.csv ${R}/navaids.csv \
      ${R}/fixes.csv ${R}/routes.csv ${R}/legs.csv ${R}/preferred.csv

dist/routes_${D}.tar.bz2 : ${CSV} | dist
	tar cvjf dist/routes_${D}.tar.bz2 ${R}

dist/routes_${D}.tar.gz : ${CSV} | dist
	tar cvzf dist/routes_${D}.tar.gz ${R}

dist/routes_${D}.zip : ${CSV} | dist
	zip -r dist/routes_${D}.zip ${R}

csv : ${CSV}

# ...comma-separated values (CSV)
#################################

dist/shortest_path.c : shortest_path.c | dist
	cp shortest_path.c dist

####################
# SQLite database...
#
dist/routes.sql : routes.sql | dist
	cp routes.sql dist

dist/routes_${D}.db.bz2 : routes_${D}.db | dist
	bzip2 -c routes_${D}.db > dist/routes_${D}.db.bz2

dist/routes_${D}.db.gz : routes_${D}.db | dist
	gzip -c routes_${D}.db > dist/routes_${D}.db.gz

dist/routes_${D}_db.zip : routes_${D}.db | dist
	- rm dist/routes_${D}_db.zip
	zip dist/routes_${D}_db.zip routes_${D}.db

routes_${D}.db : scripts/av_sqlite routes.sql ${CSV}
	- rm -f routes_${D}.db
	sqlite3 routes_${D}.db < routes.sql
	scripts/av_sqlite ${R} routes_${D}.db

# ...SQLite database
####################

##############################
# Stanford Graphbase routes...
#
dist/routes_${D}.gb.bz2 : routes_${D}.gb | dist
	bzip2 -c routes_${D}.gb > dist/routes_${D}.gb.bz2

dist/routes_${D}.gb.gz : routes_${D}.gb | dist
	gzip -c routes_${D}.gb > dist/routes_${D}.gb.gz

dist/routes_${D}_gb.zip : routes_${D}.gb | dist
	- rm dist/routes_${D}_gb.zip
	zip dist/routes_${D}_gb.zip routes_${D}.gb

routes_${D}.gb : av_sgb ${R}/fixes.csv ${R}/legs.csv
	./av_sgb ${R} routes_${D}.gb

av_sgb : av_sgb.o
	cc -o av_sgb av_sgb.o -lgb -lm
av_sgb.o : av_sgb.c
	cc -c av_sgb.c

# ...Stanford Graphbase routes
##############################

##################
# custom format...
#
nav_db : nav-${D}.bed nav-${D}.led

dist/nav-${D}.led : nav-${D}.led | dist
	cp nav-${D}.led dist

dist/nav-${D}.bed : nav-${D}.bed | dist
	cp nav-${D}.bed dist

nav-${D}.bed nav-${D}.led : ${CSV} ${T}/dof.dat scripts/av_db_cc
	scripts/av_db_cc ${T} ${R}

${T}/dof.dat : DOF_${DOFYMD}.zip | ${T}
	(cd ${T}; unzip -L -o ../DOF_${DOFYMD}.zip dof.dat)
	touch ${T}/dof.dat

DOF_${DOFYMD}.zip :
	# curl -O http://aeronav.faa.gov/content/aeronav/Digital/DOF_${DOFYMD}.zip
	#curl -O https://nfdc.faa.gov/tod/public/DOFS/DOF_${DOFYMD}.zip
	curl -O https://aeronav.faa.gov/Obst_Data/DOF_${DOFYMD}.zip

# ...custom format
##################

${R}/airports.csv : scripts/av_airports ${T}/APT.txt ${R}/README.CSV
	scripts/av_airports ${T}/APT.txt ${R}/airports.csv

${R}/runways.csv : scripts/av_runways ${T}/APT.txt ${R}/README.CSV
	scripts/av_runways ${T}/APT.txt ${R}/runways.csv

${R}/navaids.csv : scripts/av_navaids ${T}/NAV.txt ${T}/ILS.txt ${R}/README.CSV
	scripts/av_navaids ${T}/NAV.txt ${T}/ILS.txt ${R}/navaids.csv

${R}/preferred.csv : scripts/av_preferred ${T}/PFR.txt ${R}/README.CSV
	scripts/av_preferred ${T}/PFR.txt ${R}/preferred.csv

${T}/APT.txt ${T}/NAV.txt ${T}/ILS.txt ${T}/FIX.txt ${T}/PFR.txt : 28DaySubscription_Effective_${FADDS}.zip | ${T}
	(cd ${T}; unzip -L -q -o ../28DaySubscription_Effective_${FADDS}.zip)
	touch ${T}/APT.txt ${T}/NAV.txt ${T}/ILS.txt ${T}/FIX.txt ${T}/PFR.txt

${R}/fixes.csv ${R}/routes.csv ${R}/legs.csv : scripts/av_routes ${T}/AWY.txt \
	${T}/STARDP.txt ${R}/navaids.csv ${R}/airports.csv
	scripts/av_routes ${R} ${T}/AWY.txt ${T}/STARDP.txt

${T} :
	- mkdir -p ${T}

${R}/README.CSV :
	- mkdir ${R}
	cp README.CSV ${R}

dist :
	- mkdir -p dist

reallyclean : clean
	- rm -rf ${T}

clean :
	- rm routes_${D}.db routes_${D}.gb dist/routes_${D}.db.gz \
		dist/routes_${D}.db.bz2 dist/routes_${D}.tar.gz \
		dist/routes_${D}.tar.bz2 dist/routes_${D}.zip \
		${R}/airports.csv ${R}/fixes.csv ${R}/legs.csv \
		${R}/navaids.csv ${R}/routes.csv ${R}/runways.csv \
		${R}/preferred.csv \
		${R}/README.CSV nav-${D}.[bl]ed nav-${D}.txt
	- rmdir ${R}
	- rm shortest_path shortest_path.o av_sgb av_sgb.o
